==> nextcloud-23.0.9.tgz: nextcloud/apps/oauth2/l10n/pt_BR.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Seu cliente não está autorizado a conectar-se. Informe isso ao administrador.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "A URL de redirecionamento precisa ser completa, por exemplo: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Permite a autenticação compatível com OAuth2 de outros aplicativos da web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "O aplicativo OAuth2 permite que os administradores configurem o fluxo de trabalho de autenticação integrado para permitir também a autenticação compatível com OAuth2 de outros aplicativos da Web.",
    "OAuth 2.0 clients" : "Clientes OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 permite que serviços externos solicitem acesso a {instanceName}.",
    "Add client" : "Adicionar cliente",
    "Name" : "Nome",
    "Redirection URI" : "Redirecionamento URI",
    "Add" : "Adicionar",
    "Client Identifier" : "Identificador do Cliente",
    "Secret" : "Secreto",
    "Show client secret" : "Mostra senha do cliente",
    "Delete" : "Excluir"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-26.0.10.tgz: nextcloud/apps/oauth2/l10n/pt_BR.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Seu cliente não está autorizado a conectar-se. Informe isso ao administrador.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "A URL de redirecionamento precisa ser completa, por exemplo: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Permite a autenticação compatível com OAuth2 de outros aplicativos da web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "O aplicativo OAuth2 permite que os administradores configurem o fluxo de trabalho de autenticação integrado para permitir também a autenticação compatível com OAuth2 de outros aplicativos da Web.",
    "OAuth 2.0 clients" : "Clientes OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 permite que serviços externos solicitem acesso a {instanceName}.",
    "Name" : "Nome",
    "Redirection URI" : "Redirecionamento URI",
    "Client Identifier" : "Identificador do Cliente",
    "Secret key" : "Chave secreta",
    "Add client" : "Adicionar cliente",
    "Add" : "Adicionar",
    "Show client secret" : "Mostra senha do cliente",
    "Delete" : "Excluir",
    "Secret" : "Secreto"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
